@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-__version__ = '0.9.6'
-__timestamp__ = 'Thu Apr 29 15:18:54 2021 +0100'
+__version__ = '0.9.7'
+__timestamp__ = 'Wed May 5 14:14:24 2021 +0100'
 __license__ = '''
                                  Apache License
                            Version 2.0, January 2004
