@@ -316,16 +316,14 @@ class OrthoSliceViewer(pg.GraphicsView, LogSource):
         self.reset()
 
     def _focus_changed(self, focus):
-        self.debug("focus=%s, zaxis=%i", focus, self.zaxis)
+        self.debug("focus=%s", focus)
 
         if self.isVisible():
             self._vline.setPos(float(focus[self.xaxis]))
             self._hline.setPos(float(focus[self.yaxis]))
 
             if focus[self.zaxis] != self._slicez or self._vol != focus[3]:
-                self.debug("updating slice")
                 self._update_slice()
-                self.debug("updating arrows")
                 self._update_visible_arrows()
 
     def _arrows_changed(self, arrows):
