@@ -30,7 +30,8 @@ from quantiphyse.gui.plot import Plot
 from quantiphyse.gui.viewer.pickers import PickMode
 from quantiphyse.gui.widgets import QpWidget, RoiCombo, TitleWidget, RunButton
 from quantiphyse.gui.options import OptionBox, DataOption, ChoiceOption, BoolOption, TextOption, OutputNameOption
-from quantiphyse.utils import copy_table, get_kelly_col, sf
+from quantiphyse.gui.colors import get_kelly_col
+from quantiphyse.utils import copy_table, sf
 
 from .processes import CalcVolumesProcess, DataStatisticsProcess
 
@@ -615,6 +616,7 @@ class VoxelAnalysis(QpWidget):
         """
         Regenerate the plot
         """
+        self.debug("clearing plot")
         self.plot.clear() 
 
         # Get all timeseries signals
@@ -639,6 +641,7 @@ class VoxelAnalysis(QpWidget):
         #    return
         #main_curve = self.ivm.main.timeseries(pos, grid=self.ivl.grid)
 
+        self.debug("adding sigs")
         idx, _ = 0, len(sigs)
         for ovl, sig_values in sigs.items():
             if self.data_enabled[ovl] == QtCore.Qt.Checked:
