@@ -491,7 +491,8 @@ class Process(QtCore.QObject, LogSource):
         plus the logfile to the output folder
         """
         data_to_save = self.output_data_items()
-        self.debug("Data to save: %s", data_to_save)    
+        self.debug("Data to save: %s", data_to_save)
+        os.makedirs(os.path.abspath(save_folder), exist_ok=True)
         for d in data_to_save:
             qpdata = self.ivm.data.get(d, None)
             if qpdata is not None:
@@ -546,6 +547,7 @@ class Process(QtCore.QObject, LogSource):
                 # a 'finished' callback. We will fake one to make sure we get
                 # an error back. Normally this happpens because of a programming
                 # error (e.g. tried to pass a non-pickleable object)
+                # FIXME use w.get to obtain error
                 self._worker_finished_cb((idx, False, RuntimeError("Worker %i failed to start. Report this as a bug" % idx)))
                 return
 
